@@ -680,18 +680,42 @@ class ConTextMarkup(nx.DiGraph):
     def pruneModifierRelationships(self):
         """Initially modifiers may be applied to multiple targets. This function
         computes the text difference between the modifier and each modified
-        target and keeps only the minimum distance relationship"""
+        target and keeps only the minimum distance relationship
+        
+        Finally, we make sure that tehre are no self modifying modifiers present (e.g. "free" in 
+        the phrase "free air" modifying the target "free air").
+        """
         modifiers = self.getConTextModeNodes("modifier")
         for m in modifiers:
             modifiedBy = self.successors(m)
             if( modifiedBy and len(modifiedBy) > 1 ):
                 minm = min([ (m.dist(mb),mb) for mb in modifiedBy ])
                 edgs = self.edges(m)
-                if( self.getVerbose() ):
-                    print u"deleting relationship",m,minm[1]
                 edgs.remove((m,minm[1]))
+                if( self.getVerbose() ):
+                    print u"deleting relationship(s)",edgs
+
                 self.remove_edges_from(edgs)
 
+    def pruneSelfModifyingRelationships(self):
+        """
+        We make sure that tehre are no self modifying modifiers present (e.g. "free" in 
+        the phrase "free air" modifying the target "free air").
+        modifiers = self.getConTextModeNodes("modifier")
+        """
+        modifiers = self.getConTextModeNodes("modifier")
+        nodesToRemove = []
+        for m in modifiers:
+            modifiedBy = self.successors(m)
+            if( modifiedBy ):
+                for mb in modifiedBy:
+                    if( self.getVerbose() ):
+                        print mb,m,mb.encompasses(m)
+                    if( mb.encompasses(m) ):
+                        nodesToRemove.append(m)
+        if( self.getVerbose() ):
+            print "removing the following self modifying nodes",nodesToRemove
+        self.remove_nodes_from(nodesToRemove)
     def __prune_marks(self, marks):
         if( len(marks) < 2 ):
             return
